@@ -4,7 +4,7 @@
 /*								*/
 /* Some Define and Structs					*/
 /****************************************************************/
-/* bgp.h,v 1.49 2002/04/09 10:11:59 kuniaki Exp */
+/* bgp.h,v 1.53 2002/04/19 05:26:37 kuniaki Exp */
 
 /*
  * Copyright (c) 1998-2002 Internet Initiative Japan Inc.
@@ -60,9 +60,10 @@
 
 #ifdef RADIX
 #include "radix.h"
+#include "radix_v6.h"
 #endif
 
-#define BV_VERSION	"0.33Alpha"
+#define BV_VERSION	"0.34Alpha"
 #define BV_COPYRIGHT	"Copyright (c) 1998-2002 Internet Initiative Japan Inc."
 
 /* BGP Header Type field defines */
@@ -284,10 +285,12 @@ extern char	sysname[16];
 
 #ifdef RTHISTORY
 extern struct timeval	rthistcleartime;
+extern struct timeval	rthistcleartime_v6;
 #endif
 
 /* bgpview.c */
 extern void finish();
+/* extern int sourcetopn(/* char *v6adrs, char afi ); */
 extern int check_id1topn(/* net_ulong id1 */);
 
 #endif /* _BGP_H */
