@@ -4,7 +4,7 @@
 /*                                                              */
 /* BGP Message Inormations                                      */
 /****************************************************************/
-/* bgpdata.h,v 1.5 2001/09/26 07:21:22 kuniaki Exp */
+/* bgpdata.h,v 1.6 2002/04/09 09:43:03 kuniaki Exp */
 
 /*
  * Copyright (c) 1998-2000 Internet Initiative Japan Inc.
@@ -36,6 +36,11 @@
 #define _BGPDATA_H
 
 #include <sys/time.h>
+#include <time.h>
+
+#include "bgp.h"
+#include "bgplog.h"
+
 
 #define INFO_HEAD "Time                Message Update  Notific Open    Keepali Prefix  Withdra Totalpr\n"
 #define INFO_FORM "%s %7lu %7lu %7lu %7lu %7lu %7lu %7lu %7lu\n"
