@@ -4,7 +4,7 @@
 /*                                                              */
 /* Main Routine                                                 */
 /****************************************************************/
-/* bgpview.c,v 1.48 2002/04/09 09:43:04 kuniaki Exp */
+/* bgpview.c,v 1.51 2002/04/12 08:15:08 kuniaki Exp */
 
 /*
  * Copyright (c) 1998-2002 Internet Initiative Japan Inc.
@@ -68,6 +68,7 @@ char		sysname[16];
 
 #ifdef RTHISTORY
 struct timeval	rthistcleartime;
+struct timeval	rthistcleartime_v6;
 #endif
 
 int		exec_argc;
@@ -196,11 +197,14 @@ int init()
 
 #ifdef RADIX
 	init_radix();
+	init_radix_v6();
 #endif
 	strcpy(spooldir, SPOOL_DEFAULT);
 #ifdef RTHISTORY
 	rthistcleartime.tv_sec = 0;
 	rthistcleartime.tv_usec = 0;
+	rthistcleartime_v6.tv_sec = 0;
+	rthistcleartime_v6.tv_usec = 0;
 #endif
 	init_cron();
 
@@ -310,6 +314,9 @@ int init()
 	if (start_rthistclear_timer() == 1) {
 		return 1;
 	}
+	if (start_rthistclear_timer_v6() == 1) {
+		return 1;
+	}
 #endif
 
 	/* Cron read conf */
@@ -346,6 +353,30 @@ int check_id1topn(net_ulong id1)
 	return ret;
 }
 
+int sourcetopn(char *v6adrs, char afi)
+{
+        int     ret;
+
+        switch(afi) {
+        case AF_IPV4:
+                ret = check_id1topn(*((net_ulong *)v6adrs));
+                break;
+        case AF_IPV6:
+                /* source address IPv6 not supported */
+                ret = -1;
+                break;
+        }
+#ifdef DEBUG
+	{
+		char tmpv6str[50];
+		bintostrv6(v6adrs, tmpv6str);
+		printf("DEBUG: sourcetopn: v6adrs = %s, afi = %d, ret = %d\n",
+			tmpv6str, afi, ret);
+	}
+#endif
+        return(ret);
+}
+
 int check_soctopn(int soc)
 {
 	int	ret;
