@@ -3,7 +3,7 @@
 /*                                                              */
 /* BGPView Shell Commands                                       */
 /****************************************************************/
-/* bvcommand.c,v 1.54 2002/04/09 09:43:04 kuniaki Exp */
+/* bvcommand.c,v 1.57 2002/04/13 00:31:27 kuniaki Exp */
 
 /*
  * Copyright (c) 2000 - 2001 Internet Initiative Japan Inc.
@@ -333,11 +333,15 @@ int bvc_bgpsum(BVS_CMD_PARAM *prm)
 	clno = (prm->noparam).clno;
 
 	bvs_write(clno, "\r\nRoute Summary---\r\n");
-	sprintf(prline, " Received Routes   : %ld\r\n", radix_prefixes());
+	bvs_write(clno, "                     IPv4      IPv6\r\n");
+	sprintf(prline, " Received Routes   : %8ld  %8ld\r\n", 
+					radix_prefixes(), radix_prefixes_v6());
 	bvs_write(clno, prline);
-	sprintf(prline, " Received Prefixes : %ld\r\n", radix_routes());
+	sprintf(prline, " Received Prefixes : %8ld  %8ld\r\n",
+					 radix_routes(), radix_routes_v6());
 	bvs_write(clno, prline);
-	sprintf(prline, " RADIX Tree Nodes  : %ld\r\n", radix_nodes());
+	sprintf(prline, " RADIX Tree Nodes  : %8ld  %8ld\r\n",
+					 radix_nodes(), radix_nodes_v6());
 	bvs_write(clno, prline);
 
 	bvs_write(clno, "\r\nNo LocalIdentifier LoASN Neighbor        ASN   Status\r\n");
@@ -758,6 +762,17 @@ int bvc_shoversion(BVS_CMD_PARAM *prm)
 	sprintf(prline, "  Cleaning route history interval: %ld\r\n",
 							rthistcleartime.tv_sec);
 	bvs_write(clno, prline);
+	if (cleaned_time_v6 == 0) {
+		bvs_write(clno, "  Last IPv6 route history clr     : Never\r\n");
+	} else {
+		tm = localtime(&cleaned_time);
+		strftime(bufline, TIME_BUF, "%Y/%m/%d %H:%M:%S", tm);
+		sprintf(prline, "  Last IPv6 route history clr: %s\r\n", bufline);
+		bvs_write(clno, prline);
+	}
+	sprintf(prline, "  Cleaning IPv6 route histry int : %ld\r\n",
+						rthistcleartime_v6.tv_sec);
+	bvs_write(clno, prline);
 #endif
 	bvs_write(clno, "\r\n");
 	return(BVS_CNT_END);
@@ -2057,6 +2072,7 @@ int bvc_clear_route_history(BVS_CMD_PARAM *prm)
 	static int	upcode;
 	static int	curclno;
 	RADIX_T		*node;
+	static int	status;
 
 	if (prm == NULL) {
 		cnode = NULL;
