@@ -4,7 +4,7 @@
 /*                                                              */
 /* BGPView Shell Commands Header File                           */
 /****************************************************************/
-/* bvcommand.h,v 1.30 2002/04/09 09:43:04 kuniaki Exp */
+/* bvcommand.h,v 1.38 2002/04/19 05:12:20 kuniaki Exp */
 
 /*
  * Copyright (c) 2000-2001 Internet Initiative Japan Inc.
@@ -59,6 +59,7 @@
 
 #ifdef RADIX
 #include "radix.h"
+#include "radix_v6.h"
 #endif
 
 
@@ -109,34 +110,58 @@ extern int bvc_set_vtyrowsize();
 
 #ifdef RADIX
 extern int bvc_show_bgproute_all();
+extern int bvc_show_bgproute_all_v6();
 extern int bvc_output_bgproute_all();
+extern int bvc_output_bgproute_all_v6();
 extern int bvc_output_bgproute_all_nei();
+extern int bvc_output_bgproute_all_nei_v6();
 extern int bvc_show_bgproute_neighbor();
+extern int bvc_show_bgproute_neighbor_v6();
 extern int bvc_showipbgproute();
+extern int bvc_showipbgproute_v6();
 extern int bvc_show_bgproute_sum();
 extern int bvc_showipbgproutetime_eq();
 extern int bvc_showipbgproutetime_le();
 extern int bvc_showipbgproutetime_ge();
 #ifdef RTHISTORY
 extern int bvc_clear_route_history();
+extern int bvc_clear_route_history_v6();
 extern int bvc_next_rthistory_clear_set();
+extern int bvc_next_rthistory_clear_set_v6();
 extern int bvc_show_bgproute_active();
+extern int bvc_show_bgproute_active_v6();
 extern int bvc_show_bgproute_inactive();
+extern int bvc_show_bgproute_inactive_v6();
 extern int bvc_show_bgproute_all_detail();
+extern int bvc_show_bgproute_all_detail_v6();
 extern int bvc_show_bgproute_active_detail();
+extern int bvc_show_bgproute_active_detail_v6();
 extern int bvc_show_bgproute_inactive_detail();
+extern int bvc_show_bgproute_inactive_detail_v6();
 extern int bvc_show_bgproute_neighbor_active();
+extern int bvc_show_bgproute_neighbor_active_v6();
 extern int bvc_show_bgproute_neighbor_inactive();
+extern int bvc_show_bgproute_neighbor_inactive_v6();
 extern int bvc_output_bgproute_active();
+extern int bvc_output_bgproute_active_v6();
 extern int bvc_output_bgproute_active_nei();
+extern int bvc_output_bgproute_active_nei_v6();
 extern int bvc_output_bgproute_inactive();
+extern int bvc_output_bgproute_inactive_v6();
 extern int bvc_output_bgproute_inactive_nei();
+extern int bvc_output_bgproute_inactive_nei_v6();
 extern int bvc_output_bgproute_all_detail();
+extern int bvc_output_bgproute_all_detail_v6();
 extern int bvc_output_bgproute_all_detail_nei();
+extern int bvc_output_bgproute_all_detail_nei_v6();
 extern int bvc_output_bgproute_active_detail();
+extern int bvc_output_bgproute_active_detail_v6();
 extern int bvc_output_bgproute_active_detail_nei();
+extern int bvc_output_bgproute_active_detail_nei_v6();
 extern int bvc_output_bgproute_inactive_detail();
+extern int bvc_output_bgproute_inactive_detail_v6();
 extern int bvc_output_bgproute_inactive_detail_nei();
+extern int bvc_output_bgproute_inactive_detail_nei_v6();
 #endif
 #endif
 
