@@ -4,7 +4,7 @@
 /*                                                              */
 /* BGPView Shell 			                        */
 /****************************************************************/
-/* bvshell.c,v 1.58 2002/01/31 05:05:46 kuniaki Exp */
+/* bvshell.c,v 1.66 2002/04/19 05:12:21 kuniaki Exp */
 
 /*
  * Copyright (c) 2000-2002 Internet Initiative Japan Inc.
@@ -167,9 +167,13 @@ void bvs_init_set_default()
 
 	/* Static Value initialize */
 	bvc_show_bgproute_all((BVS_CMD_PARAM *)0);
+	bvc_show_bgproute_all_v6((BVS_CMD_PARAM *)0);
 	bvc_output_bgproute_all((BVS_CMD_PARAM *)0);
+	bvc_output_bgproute_all_v6((BVS_CMD_PARAM *)0);
 	bvc_output_bgproute_all_nei((BVS_CMD_PARAM *)0);
+	bvc_output_bgproute_all_nei_v6((BVS_CMD_PARAM *)0);
 	bvc_show_bgproute_neighbor((BVS_CMD_PARAM *)0);
+	bvc_show_bgproute_neighbor_v6((BVS_CMD_PARAM *)0);
 	bvc_show_bgproute_sum((BVS_CMD_PARAM *)0);
 	bvc_showipbgproutetime_eq((BVS_CMD_PARAM *)0);
 	bvc_showipbgproutetime_le((BVS_CMD_PARAM *)0);
@@ -178,6 +182,7 @@ void bvs_init_set_default()
 	bvc_show_bgpnexthop_sum_neighbor((BVS_CMD_PARAM *)0);
 #ifdef RTHISTORY
 	bvc_clear_route_history((BVS_CMD_PARAM *)0);
+	bvc_clear_route_history_v6((BVS_CMD_PARAM *)0);
 #endif
 
 	/* Entry Commands */
@@ -238,17 +243,30 @@ void bvs_init_set_default()
 #ifdef RADIX
 	bvs_entry_command(bvc_show_bgproute_all,
 			"show ip bgp", "Show BGP Route All", true);
+	bvs_entry_command(bvc_show_bgproute_all_v6,
+			"show v6 bgp", "Show IPv6 BGP Route All", true);
 	bvs_entry_command(bvc_output_bgproute_all,
 			"do output route filename %STR", 
 			"BGP ALL Route output to file", true);
+	bvs_entry_command(bvc_output_bgproute_all_v6,
+			"do output v6 route filename %STR", 
+			"BGP ALL IPv6 Route output to file", true);
 	bvs_entry_command(bvc_output_bgproute_all_nei,
 			"do output route filename %STR neighbor %ADR", 
 			"BGP ALL Route output to file from neighbor", true);
+	bvs_entry_command(bvc_output_bgproute_all_nei_v6,
+			"do output v6 route filename %STR neighbor %A46", 
+			"BGP ALL IPv6 Route output to file from neighbor", true);
 	bvs_entry_command(bvc_show_bgproute_neighbor,
 			"show ip bgp neighbor %ADR routes",
 			"Show BGP Route From Neighbor", true);
+	bvs_entry_command(bvc_show_bgproute_neighbor_v6,
+			"show v6 bgp neighbor %A46 routes",
+			"Show BGP Route From Neighbor", true);
 	bvs_entry_command(bvc_showipbgproute,
 			"show ip bgp %ADR", "Show BGP Route", true);
+	bvs_entry_command(bvc_showipbgproute_v6,
+			"show v6 bgp %V6A", "Show BGP IPV6 Route", true);
 	bvs_entry_command(bvc_show_bgproute_sum,
 			"show ip route summary",
 			"Show BGP Routes Summary", false);
@@ -265,60 +283,117 @@ void bvs_init_set_default()
 	bvs_entry_command(bvc_clear_route_history,
 			"clear route history",
 			"Cleaning Route Update/Withdraw History", false);
+	bvs_entry_command(bvc_clear_route_history_v6,
+			"clear v6 route history",
+			"Cleaning IPv6 Route Update/Withdraw History", false);
 	bvs_entry_command(bvc_next_rthistory_clear_set,
 			"set route history clear time %INT",
 			"Set Next Cleaning Route Update/Withdraw History Time", false);
+	bvs_entry_command(bvc_next_rthistory_clear_set_v6,
+			"set v6 route history clear time %INT",
+			"Set Next Cleaning IPv6 Route Update/Withdraw History Time", false);
 	bvs_entry_command(bvc_show_bgproute_active,
 			"show ip bgp active",
 			"Show BGP active routes", false);
+	bvs_entry_command(bvc_show_bgproute_active_v6,
+			"show v6 bgp active",
+			"Show IPv6 BGP active routes", false);
 	bvs_entry_command(bvc_show_bgproute_inactive,
 			"show ip bgp inactive",
 			"Show BGP inactive routes", false);
+	bvs_entry_command(bvc_show_bgproute_inactive_v6,
+			"show v6 bgp inactive",
+			"Show IPv6 BGP inactive routes", false);
 	bvs_entry_command(bvc_show_bgproute_all_detail,
 			"show ip bgp detail",
 			"Show BGP all routes with history", false);
+	bvs_entry_command(bvc_show_bgproute_all_detail_v6,
+			"show v6 bgp detail",
+			"Show IPv6 BGP all routes with history", false);
 	bvs_entry_command(bvc_show_bgproute_active_detail,
 			"show ip bgp active detail",
 			"Show BGP active routes with history", false);
+	bvs_entry_command(bvc_show_bgproute_active_detail_v6,
+			"show v6 bgp active detail",
+			"Show IPv6 BGP active routes with history", false);
 	bvs_entry_command(bvc_show_bgproute_inactive_detail,
 			"show ip bgp inactive detail",
 			"Show BGP inactive routes with history", false);
+	bvs_entry_command(bvc_show_bgproute_inactive_detail_v6,
+			"show v6 bgp inactive detail",
+			"Show IPv6 BGP inactive routes with history", false);
 	bvs_entry_command(bvc_show_bgproute_neighbor_active,
 			"show ip bgp neighbor %ADR active routes",
 			"Show BGP Active Route From Neighbor", true);
+	bvs_entry_command(bvc_show_bgproute_neighbor_active_v6,
+			"show v6 bgp neighbor %A46 active routes",
+			"Show BGP Active IPv6 Route From Neighbor", true);
 	bvs_entry_command(bvc_show_bgproute_neighbor_inactive,
 			"show ip bgp neighbor %ADR inactive routes",
 			"Show BGP Active Route From Neighbor", true);
+	bvs_entry_command(bvc_show_bgproute_neighbor_inactive_v6,
+			"show v6 bgp neighbor %A46 inactive routes",
+			"Show BGP Active IPv6 Route From Neighbor", true);
 	bvs_entry_command(bvc_output_bgproute_active,
 			"do output route filename %STR active", 
 			"BGP ALL Active Route output to file", true);
+	bvs_entry_command(bvc_output_bgproute_active_v6,
+			"do output v6 route filename %STR active", 
+			"BGP ALL Active IPv6 Route output to file", true);
 	bvs_entry_command(bvc_output_bgproute_active_nei,
 			"do output route filename %STR neighbor %ADR active", 
 			"BGP ALL Active Route output to file from neighbor", true);
+	bvs_entry_command(bvc_output_bgproute_active_nei_v6,
+			"do output v6 route filename %STR neighbor %A46 active", 
+			"BGP ALL Active IPv6 Route output to file from neighbor", true);
 	bvs_entry_command(bvc_output_bgproute_inactive,
 			"do output route filename %STR inactive", 
 			"BGP ALL In-Active Route output to file", true);
+	bvs_entry_command(bvc_output_bgproute_inactive_v6,
+			"do output v6 route filename %STR inactive", 
+			"BGP ALL In-Active IPv6 Route output to file", true);
 	bvs_entry_command(bvc_output_bgproute_inactive_nei,
 			"do output route filename %STR neighbor %ADR inactive", 
 			"BGP ALL In-Active Route output to file from neighbor", true);
+	bvs_entry_command(bvc_output_bgproute_inactive_nei_v6,
+			"do output v6 route filename %STR neighbor %A46 inactive", 
+			"BGP ALL In-Active IPv6 Route output to file from neighbor", true);
 	bvs_entry_command(bvc_output_bgproute_all_detail,
 			"do output route filename %STR detail", 
 			"BGP ALL Detail Route output to file", true);
+	bvs_entry_command(bvc_output_bgproute_all_detail_v6,
+			"do output v6 route filename %STR detail", 
+			"BGP ALL Detail IPv6 Route output to file", true);
 	bvs_entry_command(bvc_output_bgproute_all_detail_nei,
 			"do output route filename %STR neighbor %ADR detail", 
 			"BGP ALL Detail Route output to file from neighbor", true);
+	bvs_entry_command(bvc_output_bgproute_all_detail_nei_v6,
+			"do output v6 route filename %STR neighbor %A46 detail", 
+			"BGP ALL Detail IPv6 Route output to file from neighbor", true);
 	bvs_entry_command(bvc_output_bgproute_active_detail,
 			"do output route filename %STR active detail", 
 			"BGP ALL Detail Active Route output to file", true);
+	bvs_entry_command(bvc_output_bgproute_active_detail_v6,
+			"do output v6 route filename %STR active detail", 
+			"BGP ALL Detail Active IPv6 Route output to file", true);
 	bvs_entry_command(bvc_output_bgproute_active_detail_nei,
 			"do output route filename %STR neighbor %ADR active detail", 
 			"BGP ALL Detail Active Route output to file from neighbor", true);
+	bvs_entry_command(bvc_output_bgproute_active_detail_nei_v6,
+			"do output v6 route filename %STR neighbor %A46 active detail", 
+			"BGP ALL Detail Active IPv6 Route output to file from neighbor", true);
 	bvs_entry_command(bvc_output_bgproute_inactive_detail,
 			"do output route filename %STR inactive detail", 
 			"BGP ALL Detail In-Active Route output to file", true);
+	bvs_entry_command(bvc_output_bgproute_inactive_detail_v6,
+			"do output v6 route filename %STR inactive detail", 
+			"BGP ALL Detail In-Active IPv6 Route output to file", true);
 	bvs_entry_command(bvc_output_bgproute_inactive_detail_nei,
 			"do output route filename %STR neighbor %ADR inactive detail", 
 			"BGP ALL Detail In-Active Route output to file from neighbor", true);
+	bvs_entry_command(bvc_output_bgproute_inactive_detail_nei_v6,
+			"do output v6 route filename %STR neighbor %A46 inactive detail", 
+			"BGP ALL Detail In-Active IPv6 Route output to file from neighbor", true);
 #endif /* RTHISTORY */
 #endif
 	bvs_entry_command(bvc_readcronfile,
@@ -532,7 +607,7 @@ int bvs_init_start()
 
 	/**** Inline Virtual Terminal Open ****/
 #ifdef DEBUG
-	printf("DEBUG: BVS Inline VTY Open -");
+	printf("DEBUG: BVS Inline VTY1 Open -");
 #endif
 	if (((bvs_clients+bvs_maxcon-1)->clsock = open("/dev/null", O_WRONLY)) == (int)NULL){
 		printf("Inline Virtual Terminal Could not open..\n");
@@ -594,6 +669,7 @@ void *bvs_search_function(const char *cmdline, BVS_CMD_PARAM *param, boolean *mo
 	char		*bufp;
 	char		strbuf[128];
 	int		intbuf;
+	char		charbuf;
 
 	strcpy(cmd, cmdline);
 	cmdptr = strtok(cmd, " ");
@@ -694,6 +770,49 @@ void *bvs_search_function(const char *cmdline, BVS_CMD_PARAM *param, boolean *mo
 				    	return(NULL);
 				    }
 				    prmptr += 1;
+				} else if (strcmp((curptr->word)+1,"V6A")==0) {
+				    if (chkfmt(CHKFMT_V6A, words[lv]) == false) {
+				    	/* Format Error */
+				    	return(NULL);
+				    }
+				    strtobinv6(prmptr, words[lv]);
+				    prmptr += IPV6_ADDR_LEN;
+				} else if (strcmp((curptr->word)+1,"V6P")==0) {
+				    if (chkfmt(CHKFMT_V6P, words[lv]) == false) {
+				    	/* Format Error */
+				    	return(NULL);
+				    }
+				    bufp = strchr(words[lv], '/');
+				    if (bufp == NULL) {
+					/* Prefix Format Error */
+					return(NULL);
+				    } else {
+					*bufp = '\0';
+					strtobinv6(prmptr, words[lv]);
+					prmptr += IPV6_ADDR_LEN;
+					*(int *)prmptr = atoi(bufp+1);
+					prmptr += sizeof(int);
+				    }
+				} else if (strcmp((curptr->word)+1,"A46")==0) {
+				    charbuf = checkafi(words[lv]);
+#ifdef DEBUG
+				    printf("DEBUG: A46: cmd afi = %d\n", charbuf);
+#endif
+				    switch(charbuf) {
+				    case AF_IPV4:
+				    	inet_aton(words[lv], &sin);
+				    	*(net_ulong *)prmptr = sin.s_addr;
+					break;
+				    case AF_IPV6:
+				    	strtobinv6(prmptr, words[lv]);
+				    	break;
+				    default:
+				    	/* Format Error */
+				    	return(NULL);
+				    }
+				    prmptr += IPV6_ADDR_LEN;
+				    *prmptr = charbuf;
+				    prmptr++;
 				}
 		  	    } else {
 				return(NULL);
@@ -798,6 +917,7 @@ int bvs_exec_command(int clno)
 			prm.noparam.clno = clno;
 			/* Retcode is continue code */
 			ret = (*function)(&prm);
+			(bvs_clients+clno)->enable_more = false;
 			switch(ret) {
 			case 0:
 				/* Not Continue */
@@ -805,6 +925,11 @@ int bvs_exec_command(int clno)
 				break;
 			case 1:
 				/* Continue */
+				(bvs_clients+clno)->enable_more = more;
+				if (more) {
+					(bvs_clients+clno)->nextmore =
+						(bvs_clients+clno)->rowsize;
+				}
 				(bvs_clients+clno)->cont_code = 1;
 				(bvs_clients+clno)->cont_func = function;
 				memcpy(&((bvs_clients+clno)->cont_param), &prm,
@@ -838,6 +963,38 @@ int bvs_exec_command(int clno)
 	(bvs_clients+clno)->col = 0;
 }
 
+int crcheck(char *str, int len, int clno)
+{
+	char	strbuf[1024];
+	int	cnt;
+	int	ptr;
+
+	bzero(strbuf, 1024);
+	strncpy(strbuf, str, len);
+	ptr = 0;
+	cnt = 0;
+	while(strbuf[ptr] != '\0') {
+		if (strbuf[ptr] == '\n') {
+			cnt++;
+		}
+		ptr++;
+	}
+	if ((bvs_clients+clno)->enable_more) {
+		(bvs_clients+clno)->nextmore -= cnt;
+	}
+	return(cnt);
+}
+
+boolean morecheck(int clno)
+{
+	if ((bvs_clients+clno)->enable_more) {
+		if ((bvs_clients+clno)->nextmore <= 0) {
+			return(true);
+		}
+	}
+	return(false);
+}
+
 int bvs_write(int clno, char *str)
 {
 	int 		length;
@@ -888,6 +1045,7 @@ int bvs_write(int clno, char *str)
 #endif
 		}
 	}
+	/* crcheck(str, length-left, clno); */
 	return length - left;
 }
 
@@ -901,6 +1059,7 @@ int bvs_cmd_auto_complete(const char *cmdline, char *addchrs)
 	int		cptn;
 	int		nextw;
 	boolean		ftchk;
+	char		charbuf;
 
 #ifdef DEBUG
 	printf("DEBUG: BVS: complete line : '%s':%d\n",cmdline,strlen(cmdline));
@@ -962,6 +1121,17 @@ int bvs_cmd_auto_complete(const char *cmdline, char *addchrs)
 				    ftchk = chkfmt(CHKFMT_PRF, words[lv]);
 				  } else if (strcmp(curptr->word, "%INT") == 0) {
 				    ftchk = chkfmt(CHKFMT_INT, words[lv]);
+				  } else if (strcmp(curptr->word, "%V6A") == 0) {
+				    ftchk = chkfmt(CHKFMT_V6A, words[lv]);
+				  } else if (strcmp(curptr->word, "%V6P") == 0) {
+				    ftchk = chkfmt(CHKFMT_V6P, words[lv]);
+				  } else if (strcmp(curptr->word, "%A46") == 0) {
+				    charbuf = checkafi(words[lv]);
+				    if (charbuf == 0) {
+				      ftchk = false;
+				    } else {
+				      ftchk = true;
+				    }
 				  } else {
 				    ftchk = true;
 				  }
@@ -1015,6 +1185,7 @@ int bvs_cmd_pr_help(int clno, const char *cmdline)
 	char		prline[BVSC_HELPMAXC+BVSC_WRCMAX+3];
 	char		swword[BVSC_WRCMAX+1];
 	boolean		ftchk;
+	char		charbuf;
 
 #ifdef DEBUG
 	printf("DEBUG: BVS: complete line : '%s':%d\n",cmdline,strlen(cmdline));
@@ -1064,6 +1235,17 @@ int bvs_cmd_pr_help(int clno, const char *cmdline)
 			        ftchk = chkfmt(CHKFMT_PRF, words[lv]);
 			    } else if (strcmp(curptr->word, "%INT") == 0) {
 			        ftchk = chkfmt(CHKFMT_INT, words[lv]);
+			    } else if (strcmp(curptr->word, "%V6A") == 0) {
+			        ftchk = chkfmt(CHKFMT_V6A, words[lv]);
+			    } else if (strcmp(curptr->word, "%V6P") == 0) {
+			        ftchk = chkfmt(CHKFMT_V6P, words[lv]);
+			    } else if (strcmp(curptr->word, "%A46") == 0) {
+			        charbuf = checkafi(words[lv]);
+			        if (charbuf == 0) {
+			      	    ftchk = false;
+				} else {
+				    ftchk = true;
+				}
 			    } else {
 			     	ftchk = true;
 			    }
@@ -1128,6 +1310,18 @@ int bvs_cmd_pr_help(int clno, const char *cmdline)
 					    if (strcmp(ptrlist[nextw]->word,
 					    			"%SWC") == 0) {
 					    	strcpy(swword, "<ON/OFF>");
+					    } else
+					    if (strcmp(ptrlist[nextw]->word,
+					    			"%V6A") == 0) {
+					    	strcpy(swword, "<IPv6 Address>");
+					    } else
+					    if (strcmp(ptrlist[nextw]->word,
+					    			"%V6P") == 0) {
+					    	strcpy(swword, "<IPv6 Address/Len>");
+					    } else
+					    if (strcmp(ptrlist[nextw]->word,
+					    			"%A46") == 0) {
+					        strcpy(swword, "<IPv4/6 Address>");
 					    }
 					} else {
 						strcpy(swword, ptrlist[nextw]->word);
