@@ -4,7 +4,7 @@
 /*                                                              */
 /* BGPView Shell / Defines and Structs                          */
 /****************************************************************/
-/* bvshell.h,v 1.19 2002/04/09 09:43:04 kuniaki Exp */
+/* bvshell.h,v 1.22 2002/04/19 05:12:21 kuniaki Exp */
 
 /*
  * Copyright (c) 1998-2000 Internet Initiative Japan Inc.
@@ -95,6 +95,11 @@
 #define BVS_CNT_FINISH		2
 #define BVS_CNT_NOPROMPT	3
 
+typedef union address {
+	char		v6addr[IPV6_ADDR_LEN];
+	net_ulong	v4addr;
+} COMMON_ADDRESS;
+
 typedef union {
         struct {
                 int     clno;
@@ -137,6 +142,26 @@ typedef union {
                 u_long  addr;
                 boolean swc;
         } adrs_boolean;
+        struct {
+        	int	clno;
+        	char	v6addr[IPV6_ADDR_LEN];
+        } ipv6addr;
+        struct {
+        	int	clno;
+        	char	v6addr[IPV6_ADDR_LEN];
+        	int	prefixlen;
+        } ipv6prefix;
+        struct {
+        	int		clno;
+		COMMON_ADDRESS	address;
+        	char	afi;
+        } ipv46addr;
+        struct {
+        	int		clno;
+        	char		str[64];
+        	COMMON_ADDRESS	address;
+        	char		afi;
+        } onestr_ipv46addr;
 } BVS_CMD_PARAM;
 
 
@@ -154,9 +179,11 @@ typedef struct {
 	int		col;
 	int		esc;
 	int		rowsize;
+	int		nextmore;
 	int		cont_code;
 	int		(*cont_func)(BVS_CMD_PARAM *);
 	BVS_CMD_PARAM	cont_param;
+	boolean		enable_more;
 } BVS_CLIENT;
 
 typedef struct {
