@@ -4,7 +4,7 @@
 /*                                                              */
 /* Start Configuration Routine                                  */
 /****************************************************************/
-/* config.c,v 1.30 2002/03/29 03:24:02 kuniaki Exp */
+/* config.c,v 1.31 2002/04/11 10:31:24 kuniaki Exp */
 
 /*
  * Copyright (c) 1998-2002 Internet Initiative Japan Inc.
@@ -143,6 +143,10 @@ char *fname;
 			if (val == NULL) continue;
 			sscanf(val, "%ld", &rthistcleartime.tv_sec);
 			rthistcleartime.tv_usec = 0;
+		} else if (strcmp("V6RTHISTORYCLR", cmd) == 0) {
+			if (val == NULL) continue;
+			sscanf(val, "%ld", &rthistcleartime_v6.tv_sec);
+			rthistcleartime_v6.tv_usec = 0;
 #endif
 		} else if (strcmp("CRON", cmd) == 0) {
 			if (val == NULL) continue;
