@@ -4,7 +4,7 @@
 /*                                                              */
 /* Multi Protocol Extentions                                    */
 /****************************************************************/
-/* mpnlri.c,v 1.6 2002/04/09 09:43:05 kuniaki Exp */
+/* mpnlri.c,v 1.8 2002/04/12 08:15:09 kuniaki Exp */
 
 /*
  * Copyright (c) 2002 Internet Initiative Japan Inc.
@@ -71,10 +71,8 @@ int pr_mp_reach_nlri(char *ptr, int len, V6ROUTE_BUF *routebuf, int pn)
 #endif
 
 	switch(afi) {
-#ifdef HAVE_IPv6
 	case AF_IPV6:
 		break;
-#endif
 	default:
 		/* non-support AFI */
 		pr_log(VLOG_UPAT, pn, "    Unsupported AFI - Ignored\n", OFF);
@@ -178,10 +176,12 @@ int pr_mp_reach_nlri(char *ptr, int len, V6ROUTE_BUF *routebuf, int pn)
 		/* Store Prefix */
 		if (routelist == NULL) {
 			routelist = (V6ROUTE_LIST *)malloc(sizeof(V6ROUTE_LIST));
+			bzero(routelist, sizeof(V6ROUTE_LIST));
 			routebuf->preflist = routelist;
 		} else {
 			routelist->next = 
 				(V6ROUTE_LIST *)malloc(sizeof(V6ROUTE_LIST));
+			bzero(routelist->next, sizeof(V6ROUTE_LIST));
 			routelist = routelist->next;
 		}
 		store_v6addr(routelist->v6prefix, nlri);
@@ -223,10 +223,8 @@ int pr_mp_unreach_nlri(char *ptr, int len, V6ROUTE_BUF *routebuf, int pn)
 #endif
 
 	switch(afi) {
-#ifdef HAVE_IPv6
 	case AF_IPV6:
 		break;
-#endif
 	default:
 		/* non-support AFI */
 		pr_log(VLOG_UPAT, pn, "    Unsupported AFI - Ignored\n", OFF);
@@ -283,10 +281,12 @@ int pr_mp_unreach_nlri(char *ptr, int len, V6ROUTE_BUF *routebuf, int pn)
 		/* Store Prefix */
 		if (routelist == NULL) {
 			routelist = (V6ROUTE_LIST *)malloc(sizeof(V6ROUTE_LIST));
+			bzero(routelist, sizeof(V6ROUTE_LIST));
 			routebuf->preflist = routelist;
 		} else {
 			routelist->next = 
 				(V6ROUTE_LIST *)malloc(sizeof(V6ROUTE_LIST));
+			bzero(routelist->next, sizeof(V6ROUTE_LIST));
 			routelist = routelist->next;
 		}
 		store_v6addr(routelist->v6prefix, nlri);
