@@ -4,7 +4,7 @@
 /*                                                              */
 /* Routeing Information Update Routine                          */
 /****************************************************************/
-/* update.c,v 1.25 2002/04/09 09:57:01 kuniaki Exp */
+/* update.c,v 1.29 2002/04/19 05:37:44 kuniaki Exp */
 
 /*
  * Copyright (c) 1998-2000 Internet Initiative Japan Inc.
@@ -42,6 +42,7 @@
 
 #ifdef RADIX
 #include "radix.h"
+#include "radix_v6.h"
 #endif
 
 void message_dump(int pn)
@@ -358,7 +359,7 @@ void pr_update(int pn)
 			type_code = *(char *)(ptr + 1);
 			sprintf(logstr, 
 		"    Attr. Type: Attr. Flag = %02X / Attr. Type Code = %d\n",
-						*ptr, type_code);
+						*(u_char *)ptr, type_code);
 			pr_log(VLOG_UPAT, pn, logstr, OFF);
 
 			if (*ptr & 0x80) {
@@ -781,7 +782,8 @@ void pr_update(int pn)
 	if (ipv6updcnt != 0) {
 		gettimeofday(&v6getroute.lastupdate, (struct timezone *)0);
 		gettimeofday(&v6getroute.firstupdate, (struct timezone *)0);
-		store_int32(&v6getroute.source, &peer[pn].neighbor);
+		bzero(v6getroute.source, IPV6_ADDR_LEN);
+		memcpy(v6getroute.source, &peer[pn].neighbor, 4);
 		v6getroute.src_afi = AF_IPV4;
 		pr_log(VLOG_UPDE, pn, "IPv6 Routes\n", OFF);
 		pr_log(VLOG_UPDE, pn,
@@ -837,6 +839,25 @@ void pr_update(int pn)
 			pr_v6route(&v6prroute, pn);
 			write_v6prefixlog(0, &v6prroute, pn);
 
+#ifdef RADIX
+			/* Add IPv6 Route to RADIX Tree */
+			ret = add_route_v6(&v6prroute);
+			if (ret == 1) {
+				pr_log(VLOG_GLOB, pn, 
+				    "Memory Allocation Error(IPv6Add)\n", ON);
+#ifdef DEBUG
+				printf("Update Message(IPv6) -> Memory Allocation Error\n");
+#endif
+			}
+#ifdef DEBUG
+			if (ret == 2) {
+				printf("Update Message(IPv6) -> New Route\n");
+			} else if (ret == 3) {
+				printf("Update Message(IPv6) -> Update Route\n");
+			}
+#endif
+#endif
+
 			listbuf = listbuf->next;
 			cnt++;
 	
@@ -845,6 +866,29 @@ void pr_update(int pn)
 		bgpinfo[pn].prefixcnt += ipv6updcnt;
 	}
 	if (ipv6wdrcnt != 0) {
+		listbuf = v6withdraw.preflist;
+		while(listbuf != NULL) {
+#ifdef DEBUG
+			{
+				char	tmpv6str[50];
+				bintostrv6(listbuf->v6prefix, tmpv6str);
+				printf("DEBUG: V6DELETE: Prefix %s/%d\n",
+						tmpv6str, listbuf->length);
+			}
+#endif
+#ifdef RADIX
+			/* Withdraw route from radixv6 tree */
+#ifdef RTHISTORY
+			withdraw_route_v6(pn, listbuf->v6prefix, 
+					  listbuf->length, DFLAG);
+#endif
+#ifndef RTHISTORY
+			withdraw_route_v6(pn, listbuf->v6prefix,
+					  listbuf->length);
+#endif
+#endif
+			listbuf = listbuf->next;
+		}
 		write_v6prefixlog(1, &v6withdraw, pn);
 		bgpinfo[pn].withdrawcnt += ipv6wdrcnt;
 	}
